{% load pages_tags mezzanine_tags %}
<html>
<head>

    <meta http-equiv="Content-type" content="text/html; charset=utf-8" /> 
    <meta name="keywords" content="{% block meta_keywords %}{% endblock %}" /> 
    <meta name="description" content="{% block meta_description %}{% endblock %}" /> 
    <title>{% block meta_title %}{% endblock %}</title>
    <link rel="alternate" type="application/rss+xml" title="RSS" 
        href="{% url blog_post_feed "rss" %}" />
    <link rel="alternate" type="application/atom+xml" title="Atom"  
        href="{% url blog_post_feed "atom" %}" />

    <!-- 960 Grid System -->
    <link rel="stylesheet" href="{{ MEDIA_URL }}css/960/960.css" type="text/css" />
    <!-- Reset (from 960.gs) -->
    <link rel="stylesheet" href="{{ MEDIA_URL }}css/960/reset.css" type="text/css" />

    <!-- Write your customer css rules here. -->
    <link rel="stylesheet" href="{{ MEDIA_URL }}css/global.css" type="text/css" />

    {% block extra_head %}{% endblock %}

</head>
<body id="{% block body_id %}{% endblock %}">

<div id="grid-top">{% primary_menu %}</div>
<div class="container_12 clearfix">

    <div id="grid-left" class="grid_3 grid">{% tree_menu %}</div>

    <div id="grid-middle" class="grid_6 grid">
        <div class="gutter">
            <h1>{% block title %}{% endblock %}</h1>
            <div id="breadcrumb-menu">
                {% block breadcrumb_menu %}{% breadcrumb_menu %}{% endblock %}
            </div>
            {% block main %}{% endblock %}
        </div>
    </div>

    <div id="grid-right" class="grid_3 grid">
        {% include "includes/search.html" %}
        {% block right_panel %}
        {% include "twitter/tweets.html" %}
        {% endblock %}
        <p class="mezzanine">Powered by <a 
            href="http://mezzanine.jupo.org">Mezzanine</a></p>
    </div>

</div>
<div id="grid-bottom">
    <div class="container_12 clearfix">
        <div class="grid_6 push_3 grid">{% footer_menu %}</div>
    </div>
</div>

{% editable_loader %}

{% load_settings GOOGLE_ANALYTICS_ID %}
{% if GOOGLE_ANALYTICS_ID %}
<script> 
var _gaq = [['_setAccount', '{{ GOOGLE_ANALYTICS_ID }}'], ['_trackPageview']];
(function(d, t) {
var g = d.createElement(t),
    s = d.getElementsByTagName(t)[0];
g.async = true;
g.src = '//www.google-analytics.com/ga.js';
s.parentNode.insertBefore(g, s);
})(document, 'script');
</script>
{% endif %}

</body>
</html>

